/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package edu.ucsc.its.temerity.shared

import androidx.datastore.core.DataStore
import androidx.datastore.preferences.core.PreferenceDataStoreFactory
import androidx.datastore.preferences.core.Preferences
import androidx.datastore.preferences.core.edit
import androidx.datastore.preferences.core.stringPreferencesKey
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.map
import okio.Path.Companion.toPath

fun createDataStore(
  producePath: () -> String,
): DataStore<Preferences> = PreferenceDataStoreFactory.createWithPath(
  corruptionHandler = null,
  migrations = emptyList(),
  produceFile = { producePath().toPath() },
)

class AppSettings(private val dataStore: DataStore<Preferences>) {

  val userServiceEndpoint: Flow<String> = dataStore.data.map { preferences ->
    preferences[USER_ENDPOINT_URL_SETTING] ?: ""
  }

  val userAuthToken: Flow<String> = dataStore.data.map { preferences ->
    preferences[USER_AUTH_TOKEN_SETTING] ?: ""
  }

  suspend fun updateServiceEndpoint(newEndpointUrl: String) {
    dataStore.edit { preferences ->
      preferences[USER_ENDPOINT_URL_SETTING] = newEndpointUrl
    }
  }

  suspend fun updateUserAuthToken(newToken: String) {
    dataStore.edit { preferences ->
      preferences[USER_AUTH_TOKEN_SETTING] = newToken
    }
  }

  companion object {
    val USER_AUTH_TOKEN_SETTING = stringPreferencesKey("user_auth_token")
    val USER_ENDPOINT_URL_SETTING = stringPreferencesKey("user_endpoint_url")
  }
}
