/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package edu.ucsc.its.temerity.shared.database

import androidx.room.Database
import androidx.room.RoomDatabase
import androidx.room.TypeConverter
import androidx.room.TypeConverters
import edu.ucsc.its.temerity.remote.Device
import edu.ucsc.its.temerity.remote.Group
import edu.ucsc.its.temerity.remote.User
import kotlinx.datetime.LocalDateTime

internal const val DB_FILENAME = "temerity.db"

@Database(entities = [Group::class, User::class, Device::class], version = 1)
@TypeConverters(LocalDateTimeConverter::class)
abstract class AppDatabase : RoomDatabase() {
  abstract fun temerityDao(): TemerityDao
}

class LocalDateTimeConverter {
  @TypeConverter
  fun fromTimestamp(value: String?): LocalDateTime? {
    return value?.let { LocalDateTime.parse(it) }
  }

  @TypeConverter
  fun dateToTimestamp(date: LocalDateTime?): String? {
    return date?.toString()
  }
}
