/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package edu.ucsc.its.temerity.shared.data

import androidx.datastore.core.DataStore
import androidx.datastore.preferences.core.Preferences
import androidx.room.Room
import androidx.sqlite.driver.bundled.BundledSQLiteDriver
import edu.ucsc.its.temerity.shared.createDataStore
import edu.ucsc.its.temerity.shared.database.AppDatabase
import edu.ucsc.its.temerity.shared.database.DB_FILENAME
import org.koin.core.context.GlobalContext.get
import org.koin.core.parameter.parametersOf
import org.koin.dsl.module
import java.io.File

internal actual fun storageModule() = module {
  single { dataStore() }
  single<AppDatabase> { createRoomDatabase() }
}

fun createRoomDatabase(): AppDatabase {
  val appDataDir = get().get<String> { parametersOf("edu.ucsc.its.temerity") }
  val dbFile = File(appDataDir, DB_FILENAME)
  return Room.databaseBuilder<AppDatabase>(
    name = dbFile.absolutePath,
  )
    .setDriver(BundledSQLiteDriver())
    .build()
}

fun dataStore(): DataStore<Preferences> =
  createDataStore(
    producePath = { "temerity.preferences_pb" },
  )
