/*
 *     Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 *     Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 *     This library is free software; you can redistribute it and/or
 *     modify it under the terms of the GNU Lesser General Public
 *     License as published by the Free Software Foundation; version 2.1 of the License.
 *
 *     This library is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *     Lesser General Public License for more details.
 *
 *     You should have received a copy of the GNU Lesser General Public
 *     License along with this library; if not, write to the Free Software
 *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package edu.ucsc.its.temerity

import io.kotest.core.spec.style.FunSpec
import kotlinx.coroutines.runBlocking
import org.dotenv.vault.dotenvVault

class DevDeviceApiTests : FunSpec({
  val dotenv = dotenvVault()

  lateinit var classUnderTest: PlatformClient

  beforeTest {
    classUnderTest = platformClient {
      debugEnabled(true)
      serviceEndpoint(dotenv["YUJADEV_API_URL"])
      serviceToken(dotenv["YUJADEV_TOKEN"])
    }
  }

  test("4.2.1 - PlatformClient can fetch a list of devices") {
    runBlocking {
      val returnedDevices = classUnderTest.getDevices()
      println("Returned devices:")
      returnedDevices.forEach { println(it) }
      assert(returnedDevices.isNotEmpty())
    }
  }
})
